/*====================================================================
File:         00master.do
Task:         Setup and execution of analysis
Project:      Your thesis
Author(s):    Your name
Updated:      2015-03-06                                                                                    
====================================================================*/


/*-------------------------------------------------------------------- 
This do-file:

@1 installed necessary additional packages
@2 specifies globals for working directory and subdirectories
@3 shows the order of the code files (and executes them)
--------------------------------------------------------------------*/

version 13.1       // Stata version control (adjust version if necessary)
clear all          // clear STATA working memory
macro drop _all    // clear all macros
set linesize 80    // determines the line width in the results window
set more off       // prevents pausing of the output


/*--------------------------------------------------------------------
@1 Install additional packages (Ado-files)

Ado files are commands written by Stata users that must be installed
separately before using them for the first time.                                                       
--------------------------------------------------------------------*/

ssc install estout, replace   // creates tables from Stata output


/*--------------------------------------------------------------------
@2 Specify globals for working directory and subdirectories

Globals are macros that allow the same code to be used at different
in different places in the do-file. Unlike locals globals are 
applicable across different do-files.

For directories, globals are useful, because they only have to 
be defined once and can then be used across all do-files.

For this purpose, before each execution of the remaining do-files 
only the master file must be executed.

In the following a global for the working directory will be defined.
This will then be used to create globals for all subdirectories.

Please note: 
Windows users must specify the drive letter at the beginning of the
path.
--------------------------------------------------------------------*/

* Working directory (Insert your own working directory here!)
global workdir "/Users/wmb222/Dropbox/Arbeit/Lehre/ptcl_thes/template"

* Subdirectories (nothing has to be changed here)
global origdat "${workdir}/data/original"   // for original data
global prepdat "${workdir}/data/prepared"   // for derived data
global code    "${workdir}/code"            // for code files
global graphs  "${workdir}/figures"         // for figures
global tables  "${workdir}/tables"          // for tables / output
global cbook   "${workdir}/docu/codebooks"  // for codebooks


/*--------------------------------------------------------------------
@3 Show names and order of used code files

If you remove the *, the respective code file is executed by the 
command do is executed.

Thus, by executing the entire master file, after adjusting the working 
directory and the Stata version, the entire data preparation and 
analysis should proceed without errors.

Please test this.
--------------------------------------------------------------------*/

*do "${code}/01cr_andata.do"  // creates analysis dataset
*do "${code}/02an_verify.do"  // checks analysis dataset
*do "${code}/03an_sample.do"  // describes sample
*do "${code}/04an_result.do"  // executes analysis


*====================================================================*
