/*====================================================================
File:         01cr_andata.do
Task:         Creates data set for analysis
Project:      Your thesis
Author(s):    Your name
Updated:      2015-03-06                                                                              
====================================================================*/


/*--------------------------------------------------------------------
This do-file:

@1 imports original data
@2 recodes variables for the analysis and creates new variables
@3 defines the analytic sample
@4 labels variables and their values
--------------------------------------------------------------------*/


/*--------------------------------------------------------------------
@1 Import and inspect original data
--------------------------------------------------------------------*/

* Load original data using the global
use "${origdat}/tdat_v_1_0_0.dta", clear


* Inspect data
describe               // shows all variables
notes                  // shows all annotations
codebook, problems     // indicates potential problems
duplicates report id   // Are there duplicate observations?


* Keep only relevant variables
keep id      /// ID-Variable
     var1    /// Variable 1
     var2    /// Variable 2
     var3    //  Variable 3
	 
	 
/*--------------------------------------------------------------------
@2 Recode variables and create new variables

Always comment your recodings etc. in detail.
By using the "note" command, you can also add annotations to the 
data set for individual variables.                                                 
--------------------------------------------------------------------*/	 
	 
* Renaming variable 1
rename var1 avar


* quadratic term for variable 2
gen qvar2 = var2^2

note qvar2: generates qvar2 = var2 * var2

sum qvar qvar2  // Comparison for control
* categories for variable 3 (generates new variable)
recode var3                ///
       (-5/-1 = 0 "Kat 0") ///
       (0/3   = 1 "Kat 1") ///
       (4/6   = 2 "Kat 2") ///
       , gen(katvar3)

tab var3 katvar3  // Comparison for control

note katvar3: derived from var3 with 3 categories 1=(-5/-1) ///
		2=(0/3) 3=(4/6)


/*--------------------------------------------------------------------
@3 Define analytic sample(s)

selection criteria for sample 1
    1. categories 1 and 2 of categorial variable 3 only
	2. no missing values with respect to all relevant variables

This is where you create the variables that account for your 
analytic sample(s).
For example, you may want to look only at employed persons, 
or only at a certain age group, etc.

In the case of multistage selection, it makes sense to generate several 
sample variables in order to be able to track the reduction in the 
number of cases due to exclusion criteria and the like later on.
--------------------------------------------------------------------*/

gen sample1 = katvar3 < 2 /// categorien 0 und 1 only
            & avar    < . /// no missings
            & var2    < . /// 

note sample1: categories 0 and 1 only and no missing values          

/*--------------------------------------------------------------------
@4 label variables and their values

For different categor. variables with the same expressions, e.g. 
dummies with 0=no and 1=yes, the same value label can be used. 
This has to be defined only once and then assigned to the individual 
variables.
For metric variables, value labels usually do not make sense.
--------------------------------------------------------------------*/

* Definition of value labels
label def yesno   0 "no" 1 "yes"


* Assigning the value labels
label val katvar3 yesno
label val sample1 yesno


* Labels for variables
label var id        "ID variable"
label var avar      "variable 1"
label var var2      "variable 2"
label var qvar2     "variable squared"
label var katvar3   "variable 3"
label var sample1   "analytic sample 1"

			
*--------------------------------------------------------------------*

* keep variables relevant for the analysis
keep avar var2 qvar2 katvar3 id sample


* sort variables as you wish
order id avar var2 qvar2 katvar3 sample


* Sort dataset by ID variable
sort id


* label for dataset
label data "template analytic dataset for final thesis"


* note about dataset
note: derived from Template Data v.1.0.0


* saving dataset in directory for created data
save "${prepdat}/andata.dta", replace


*====================================================================*
