/*====================================================================
File:         02an_verify.do
Task:         Checks analytic dataset and generates codebook
Project:      Your thesis
Author(s):    Your name
Updated:      2015-03-06                                                                               
====================================================================*/


/*-------------------------------------------------------------------- 
This do-file:

@1 checks dataset for possible problems
@2 checks variables and their values and missings
@3 performs content checks on the variables
@4 generates codebook of the analytic dataset 
--------------------------------------------------------------------*/


/*--------------------------------------------------------------------
@1 Check dataset for possible problems

Examples for possible problems are:
- wrong sorting
- missing information
- incomplete variable labels
- variables with only one value (constants) 
- duplicate observations (no unique id)

help codebook problems provides further hints
                                                         
--------------------------------------------------------------------*/

use "${prepdat}/andata.dta", clear // open analytic dataset

notes                  // shows all annotations
describe               // shows all variables (and sorting)
codebook, problems     // indicates potential problems
duplicates report id   // are there duplicate observations?


/*--------------------------------------------------------------------
@2 check variables and their values missings

Here you check whether the individual expressions of the variables 
are coded as desired and whether the labels correspond to these.

Some example commands for this are listed.                                                      
--------------------------------------------------------------------*/

codebook, compact  // shows most important distribution parameters

inspect            // shows distribution and number of cases 
		      of all variables

tab katvar         // for checking categorical variables

dotplot avar var2 qvar2 // comparative scatterplot


/*--------------------------------------------------------------------
@3 Check variables for contents

Examples are:
- Are the variables distributed as expected?
- Are there any outliers?
- Do certain variables correlate as one would expect e.g. 
education and income

Some example commands for this are listed.                                                           
--------------------------------------------------------------------*/

stem avar                      // Distribution plot

hist var2                      // Histogram

tab katvar3                    // for categorial variables

twoway scatter avar var2,     /// Scatter-Plot
       jitter(8)              ///
       msymbol(circle_hollow) ///
       ylabel(, grid)         ///
       xlabel(, grid)         ///
       aspectratio(1)

graph matrix avar-katvar3 , jitter(3) /// Scatter-Plot-Matrix
      half msymbol(circle_hollow)


/*--------------------------------------------------------------------
@4 Generate codebook for analytic dataset

For this purpose the command "codebook" can be used.
Via a log-file the output can then be saved in the designated folder.
--------------------------------------------------------------------*/

capture log close
log using "${cbook}/cb_andata.txt", replace text
codebook
log close


*====================================================================*
