/*====================================================================
File:         03an_sample.do
Task:         Provides description of analytic dataset 1
Project:      Your thesis
Author(s):    Your name
Updated:      2015-03-06                                                                                    
====================================================================*/


/*--------------------------------------------------------------------
This do-file:

@1 Opens analytic dataset and contains sample to be described
@2 Describes distributions and most important parameters of the sample
--------------------------------------------------------------------*/


/*--------------------------------------------------------------------
@1 Open analytic dataset and keep sample to be described                                                      
--------------------------------------------------------------------*/

use "${prepdat}/andata.dta", clear // open analytic dataset

keep if sample1 == 1               // keep sample only

drop sample                        // delete sample indicator                      


/*--------------------------------------------------------------------
@2 Describe analytic datset

This includes:
- distributions 
- distribution parameters (e.g. median, mean, minimum/maximum, SD)
- case numbers

Histograms are useful for the graphical representation of
distributions

For the creation of tables the command "tabstat" is very suitable.

Created figures should be exported with correct name directly to 
the corresponding directory
Different formats are possible here: pdf, tiff, eps, jpg
See the graph export help for more details.

Created tables can be exported either via log-files or via the 
estout-Ado.

The latter has the advantage that the tables can be directly 
converted to a format for further text processing (e.g. Word, Latex).
There are numerous options for this, for which it is worthwhile to 
look at the help (help estout).

Tables should also be placed directly in the corresponding folder.

Label different analyses with capital letters and indicate where 
exactly in your work these analyses appear.                                                     
--------------------------------------------------------------------*/

* A: Distributions by histogram, Fig. 1, p. 29
hist avar, scheme(s1mono) bcolor(black) fcolor(white) ///
           note("Code: 03an_sample.do@2A", size(tiny))

graph export "${graphs}/abb1.pdf", replace


* B: Table with selected univariate statistics, Tab. 1, p.30
estpost tabstat avar var2 katvar3, listwise         ///
                stat(min max p50 mean sd) col(stat) 

esttab . using "${tables}/tab1.rtf", replace                   ///
         cells("min(fmt(%5.3f)) max p50 mean sd") label nonum  ///
         note("Code: 03an_sample.do@2B2")


*====================================================================*
