/*====================================================================
File:         04an_result.do
Task:         Execution of analysis
Project:      Your thesis
Author(s):    Your name
Updated:      2015-03-06                                                                                    
====================================================================*/


/*--------------------------------------------------------------------
This do-file:

@1 creates tables
@2 creates figures

If you perform a large number of analyses, it is advisable to create 
a separate do-file for each partial analysis.
--------------------------------------------------------------------*/

set cformat %5.3f  // defines format for coefficients etc.
set pformat %4.3f  // defines formats for p-values
set sformat %5.3f  // defines formats for test statistics                    


/*--------------------------------------------------------------------
@1 Create tables (e.g. regression tables)   

Analysis results can be exported either via log-files or via the 
estout-Ado.

The latter has the advantage that the tables can be directly 
converted to a format for further text processing (e.g. Word, Latex).
There are numerous options for this, for which it is worthwhile to 
look at the help (help estout).

Tables should also be placed directly in the appropriate folder.

Indicate different analyses with capital letters in each case
and specify where exactly in your work the analysis appears.                                                    
--------------------------------------------------------------------*/

use "${prepdat}/andata.dta", clear // open analytic dataset
keep if sample1 == 1               // keep sample only
drop sample                        // delete sample indicator 

* stepwise regression analysis, Tab. 2, p. 35
reg avar var2
est store A2a

reg avar var2 qvar2
est store A2b

reg avar var2 qvar2 katvar3 
est store A2c

esttab A2a A2b A2c using "${tables}/tab2.rtf", replace label  ///
       nostar nodep nonum ci b(%5.3f) r2 obslast              ///
       mtitles("Modell 1" "Modell 2" "Modell 3") compress     ///
       note("Code: 04an_result.do@1;"                         ///
	        "note: 95%-CI in square brackets")


/*--------------------------------------------------------------------
@2 Create graphics    

Created images should be exported with correct name directly into the 
corresponding directory.
Different formats are possible here: pdf, tiff, eps, jpg.
See the graph export help for more details.                                                 
--------------------------------------------------------------------*/

use "${prepdat}/andata.dta", clear // open analytic dataset 
keep if sample1 == 1               // keep sample only
drop sample                        // delete sample indicator 

* Scatter-Plot with linear prediction, Fig. 2, p. 37
twoway (scatter avar var2, jitter(8)                           ///
                           mcolor(gs8) msymbol(circle_hollow)) ///
       (lfit    avar var2, lcolor(black) lpattern(solid))      ///
      , ylabel(-3.5(.5)3.5, grid gmin angle(0) format(%2.1f))  ///
        xlabel(-12(2)14, grid gmin)                            ///
        ytitle("Variable 1") xtitle("Variable 2")              ///
        legend(order(2) label(2 "linear prediction"))         ///
        aspectratio(1) scheme(s1mono) xsize(4) ysize(4)        ///
        note("Code: 03an_result.do@2", size(tiny))

graph export "${graphs}/abb2.pdf", replace

*====================================================================*
